#!/bin/sh
#################################################################
#
#  File Name:   rfxconfig.sh
#
#  Module Abstract:
#   This module contains the Bourne shell script which will 
#   automatically generate the environment required to run
#   the RasterFLEX windowing environment based upon the manner
#   in which software installation was performed.
#
#################################################################

#################################################################
# Copyright (c) 1998 Visicom
#################################################################

#################################################################
# The current version.
#################################################################

Version='5.0'

#################################################################
# The year.
#################################################################

Year=`date +19%y`

#################################################################
# The list of software installation options.
# Note: This list and the associated strings must *exactly* match 
# the ones in the Butler 
#################################################################
ItemList="\
    VITrdrvr \
    VITrinstl \
    VITropwin \
    VITrfddx \
    VITrxfont \
    VITrxman \
    VITrxserv \
    VITrxsupt \
    "

#################################################################
# The constructed executable search path
#################################################################
ExecPath=""

#################################################################
# The constructed shared library search path
#################################################################
LibraryPath=""

#################################################################
# The constructed manual page search path
#################################################################
ManPath=""

#################################################################
# Overlay Mode
#################################################################
OverlayMode=""

#################################################################
#
# Echo Argument*
#
#   Argument    An argument to print.
#
# Action
#
#   Echos the given arguments to the controlling terminal without
#   appending a newline.
#
# Return Value
#
#   None
#
#################################################################

Echo()
{
echo -n "$*" > /dev/tty
}

#################################################################
#
# EchoLn Argument*
#
#   Argument    An argument to print.
#
# Action
#
#   Echos the given arguments to the controlling terminal with a
#   newline appended.
#
# Return Value
#
#   None
#
#################################################################

EchoLn()
{
echo "$*" > /dev/tty
}

#################################################################
#
# FormatText
#
# Action
#
# Formats text using nroff
#
# Return Value
#
#   None
#
#################################################################
FormatText()
{
EchoLn ""
nroff <<END_OF_FILE | sed -n -e '/^END_OF_FILE/q;p'
.nh
.fi
.pl 24
.ll 70
$1
END_OF_FILE
}

#################################################################
#
# PrependPath NewItem Path
#
#   NewItem     The new item which is be added to the path 
#   Path        The variable which contains the path 
#
# Action
#
#   Modifies the value of the variable Path which is assumed to
#   be a search path variable by prepending the item NewItem to
#   the front of it.
#
# Return Value
#
#   None.
#
#################################################################
PrependPath()
{
NewItem="$1"
Path="$2"
eval CurPath=\$$Path

#################################################################
# Add the item.  If the path is currently empty, just set it to
# the new item, otherwise, prepend the new item and colon 
# separator.
#################################################################
if [ -n "$CurPath" ]
then
    #################################################################
    # Check to see if the item is already in the list
    #################################################################
    if [ `expr "$CurPath" ':' ".*$NewItem\$"` -eq '0'  -a \
         `expr "$CurPath" ':' ".*$NewItem\:.*"` -eq '0' ]
    then
        eval $Path=$NewItem\:$CurPath
    fi
else
    eval $Path=$NewItem
fi
}

#################################################################
#
# SIGINTHandler
#
# Action
#
#   Receives and processes an interrupt.
#
# Return Value
#
#   None.
#
#################################################################

SIGINT_handler()
{
rm -r $TarTempDir >/dev/null 2>&1

EchoLn ""
EchoLn "*********************************************"
EchoLn "* RasterFLEX Software Configuration Aborted *" 
EchoLn "*********************************************"
EchoLn ""
exit 1
}

trap 'SIGINT_handler' 2

#################################################################
# MAIN
#################################################################

#################################################################
# Examine the software installation.
#################################################################
FormatText "\
Scanning the current RasterFLEX software installation.  
Please be patient...
.sp
.br
END_OF_FILE
"

#################################################################
# Now find the package items in the item list.  When found,
# save the destination directory for the item and continue.
#################################################################
for SearchItem in $ItemList
do
    pkginfo -q $SearchItem
    if [ $? -ne 0 ]
    then 
        eval ${SearchItem}Dir=""
    else
	echo "Package: $SearchItem	`pkgparam $SearchItem NAME`"
        eval ${SearchItem}Dir="`pkgparam ${SearchItem} RFXTOP`"
    fi 
done

#################################################################
# Check the device driver installation
#################################################################
if [ -z "$VITrdrvrDir" ]
then
    FormatText "\
It does not appear that you have loaded the most recent version
($Version) of the device driver onto your system.  Please follow the
installation instructions in the RasterFLEX Software Release notes to
properly install and load the device driver before continuing.
.sp
The RasterFLEX device driver must be installed on the system in order to
run all other software in the RasterFLEX software release.
.sp
.br
END_OF_FILE
"
    exit 0
fi

#################################################################
# Check to see if OpenWindows 3.x has been installed on this
# machine.
#################################################################
if [ -z "$OPENWINHOME" ]
then

    if [ -z "`pkginfo SUNWowrqd`" ]
    then

    	FormatText "\
The OpenWindows environment does not appear to be installed on this
system because the SUNWowrqd (OpenWindows required core package)
package could not be located.
The OPENWINHOME environment variable is usually set to point to the
directory into which OpenWindows has been installed.   You must have
the OpenWindows environment installed in order to run the RasterFLEX
X11/NeWS or Loadable DDX Window System environments.
.sp
.br
END_OF_FILE
"
        ans=`ckyorn -p -d y "Is OpenWindows installed on this system? <y>"` || exit $?
        if [ "$ans" = y -o "$ans" = "yes" ]
        then
             while :
             do
                 #############################################################
                 # Prompt for the OpenWindow directory and validate it.
                 #############################################################
                 OPENWINHOME=`ckpath -o -p "Enter location of OpenWindows installation"` || exit $?
                 if [ -d $OPENWINHOME/bin -a -d $OPENWINHOME/lib -a -f $OPENWINHOME/bin/xnews ]
                 then
                     break
                 else

                     FormatText "\
The directory which you entered, $OPENWINHOME, does not appear to be the
top level directory of the OpenWindows release tree.  The directory you
enter should be an appropriate value for
the OPENWINHOME environment variable.  Refer to the OpenWindows 3.0
Installation Guide from Sun for more information on the use of the
OPENWINHOME environment variable.
.br
.sp
END_OF_FILE
"
                 fi

                 #############################################################
                 # If the entered directory was not validated, allow a retry
                 #############################################################
                 ans=`ckyorn -d y -p "Would you like to respecify the directory? <y>"` || exit $?
                 if [ "$ans" = y -o "$ans" = "yes" ]
                 then
                     :
                 else
                      OPENWINHOME=""
                      VITropwinDir=""
                      VITrfddxDir=""
                      break;
                 fi
             done
        fi

    #################################################################
    # Derive the OPENWINHOME environment variable from the location
    # of the SUNWowrqd package
    #################################################################
    else
##        OPENWINHOME="`pkgparam SUNWowrqd BASEDIR`/openwin"
	  OPENWINHOME="/usr/openwin"
    fi
fi

if [ -n "$OPENWINHOME" ]
then
    FormatText "\
This configuration tool can generate the information required to run the
standard OpenWindows clients, demonstrations, and DeskSet tools.
.br
END_OF_FILE
"
    ans=`ckyorn -d y -p "Would you like to use the OpenWindows environment? <y>"` || exit $?
    if [ $ans = y -o $ans = yes ] 
    then
        PrependPath $OPENWINHOME/bin ExecPath
        PrependPath $OPENWINHOME/demo ExecPath
        PrependPath $OPENWINHOME/lib LibraryPath
        PrependPath $OPENWINHOME/man ManPath
    else
        OPENWINHOME=""
        VITropwinDir=""
        VITrfddxDir=""
    fi
fi

#################################################################
# If the manual pages are installed in a location other
# than /usr/man, add their location to the manual page search
# path.
#################################################################
if [ -n "$VITropwinDir" -a "$VITopwinDir" != "/usr" ]
then
    PrependPath $VITropwinDir/man ManPath
fi
if [ -n "$VITrxmanDir" -a "$VITrxmanDir" != "/usr" ]
then
    PrependPath $VITrxmanDir/man ManPath
fi

#################################################################
# If the X11R5 clients are loaded, ensure that the development
# environment is loaded also since R5 shared libraries are required.
#################################################################
if [ -n "$VITrxsuptDir" ]
then

    #################################################################
    # If the X11R5 client programs were loaded, add their location
    # to the executable path and the X11R5 shared library location
    # to the environment variable path.
    #################################################################
    PrependPath $VITrxsuptDir/bin ExecPath
    PrependPath $VITrxsuptDir/lib LibraryPath
fi

#################################################################
# Check for no window system installed. 
#################################################################
if [ -z "$VITropwinDir" -a -z "$VITrxservDir" -a -z "VITrfddxDir" ]
then
    FormatText "\
You do not appear to have installed either the RasterFLEX X11/NeWS,
RasterFLEX X11R5, or RasterFLEX Loadable DDX Packages.  You must 
have one of these packages installed in order to run a window system
on the RasterFLEX accelerator.
.sp
Please repeat the software installation process and ensure that you
have selected one of the window system packages to install.
.sp 
.br
END_OF_FILE
"
    exit 0
fi

#################################################################
# If both X11/NeWS and X11R5 environments have been installed,
# ask the user to select which one to configure.
#################################################################
if [ -n "$VITropwinDir" -a -n "$VITrxservDir" ]
then

    FormatText "\
You have elected to install both the RasterFLEX X11/NeWS server and the
RasterFLEX X11R5 server.  Please select the server which you would like
me to configure for you to run when you start up a window system on the
RasterFLEX.
.sp
Note: You can always rerun the Software Configuration Mechanic later to
change your selection.
.sp 
.br
END_OF_FILE
"

    X11NeWS="X11/NeWS X11/NeWS Window System"
    X11R5="X11R5 X11 Release 5 Window System"

    SysSel=`ckitem -n -p "Select the desired window system:" "$X11NeWS" "$X11R5"` || exit $?
    if [ $SysSel = "X11/NeWS" ]
    then
        VITrxservDir=""
    else
        VITropwinDir=""
    fi
fi

#################################################################
# If both Loadable DDX and X11R5 environments have been installed,
# ask the user to select which one to configure.
#################################################################
if [ -n "$VITrfddxDir" -a -n "$VITrxservDir" ]
then

    FormatText "\
You have elected to install both the RasterFLEX Loadable DDX Environment 
and the
RasterFLEX X11R5 Environment.  Please select the the server which you would like
me to configure for you to run when you start up a window system on the
RasterFLEX.
.sp
Note: You can always rerun the Software Configuration Mechanic later to
change your selection.
.sp 
.br
END_OF_FILE
"

    LoadDDX="DDX OpenWindows Window System with Loadable DDX"
    X11R5="X11R5 X11 Release 5 Window System"

    SysSel=`ckitem -n -p "Select the desired window system:" "$LoadDDX" "$X11R5"` || exit $?
    if [ $SysSel = "DDX" ]
    then
        VITrxservDir=""
    else
        VITrfddxDir=""
    fi
fi

#################################################################
# If both Loadable DDX and X11/NeWS environments have been installed,
# decide which one to configure based upon the current operating
# system.  X11/NeWS is supported for Solaris 2.1 and 2.2, and
# Loadable DDX is supported for Solaris 2.3 and later.
#################################################################
if [ -n "$VITrfddxDir" -a -n "$VITropwinDir" ]
then
    case `uname -r` in
        5.[012])
            VITrfddxDir=""
            ;;
        *)
            VITropwinDir=""
            ;;
    esac
fi

#################################################################
# Check to see if the X11R5 server was loaded/selected, but the
# R5 font directories were not.
#################################################################
if [ -n "$VITrxservDir" ]
then

    #################################################################
    # Ensure that the server bin directory is on the executable path 
    #################################################################
    PrependPath $VITrxservDir/bin ExecPath

    #################################################################
    # Build a font path option for the server (if non-default)
    #################################################################
    if [ -n "$VITrxfontDir" ]
    then
        XFontsDir=$VITrxfontDir/lib/X11/fonts
        if [ $VITrxfontDir != "/opt/VITrflex" ]
        then
            XFontPath="-fp $XFontsDir/misc,$XFontsDir/100dpi,$XFontsDir/75dpi,$XFontsDir/Speedo"
        else
            XFontPath=""
        fi

    else
        FormatText "\
You have elected to install the X11R5 Server & Color Database, but not the 
X11R5 Server Fonts.  A set of X11R5 fonts are required to use the RasterFLEX
X11R5 Server.  If you already have a set of X11R5 fonts loaded on your
system, you may use them with the RasterFLEX server.
.sp
.br
END_OF_FILE
"

        ans=`ckyorn -d n -p "Do you have a set of X11 Fonts which you would like to use? <n>"` || exit $?
        if [ $ans = y -o $ans = yes ] 
        then

            FormatText "\
You must specify a valid font path to select the X11 font directories which
you have installed on your system.  The font path should be in the format
expected by the \"-fp\" option to Xrfx.  Remember to separate multiple
directory names with a comma and do not embed any spaces in the font path.
.sp
Refer to the RasterFLEX User's Guide for more information on the Font Path
(-fp) option to the X11R5 Server.
.sp
.br
END_OF_FILE
"

            XFontPath="-fp `ckpath -o -p 'What font path would you like to use'`"
        else

            FormatText "\
You must have a valid set of X11 Fonts installed on your system in 
order to use the RasterFLEX X11R5 Window System environment.  Please
perform the software installation again and ensure that the X11R5 Server
Fonts are installed.
.sp
Once you have installed the fonts properly, you may invoke me again to
configure your system.
.sp
.br
END_OF_FILE
"
            exit 0
        fi
    fi

    #################################################################
    # Build a color database option for the server (if non-default)
    #################################################################
    if [ $VITrxservDir != "/opt/VITrflex" ]
    then
        XRGBPath="-co $VITrxservDir/lib/X11/rgb"
    else
        XRGBPath=""
    fi

    #################################################################
    # Ensure that the server bin directory is on the executable path 
    #################################################################
    ServerString="$VITrxservDir/bin/Xrfx -dev /dev/rfx0 $XFontPath $XRGBPath"
    OpenwinOptions=""

    WindowSystem="X11R5"
fi

if [ -n "$VITropwinDir" ]
then
    #################################################################
    # Ensure that the server bin directory is on the executable path 
    #################################################################
    PrependPath $VITropwinDir/bin ExecPath
    ServerString="$VITropwinDir/bin/xnews-rfx -dev /dev/rfx0"
    OpenwinOptions=""
    
    WindowSystem="X11NEWS"
fi

if [ -n "$VITrfddxDir" ]
then
    #################################################################
    # Set the server string 
    #################################################################
    ServerString="$OPENWINHOME/bin/Xsun"
    OpenwinOptions="-dev /dev/rfx0"
    
    WindowSystem="DDX"
fi

if [ -n "$OPENWINHOME" ]
then
    OpenWinStr="or \"openwin\""
else
    OpenWinStr=""
fi

#################################################################
# Allow selection of configuration options. 
#################################################################
FormatText "\
The RasterFLEX accelerators support several configuration options
including the overlay mode and the default visual class/depth.  The 
RasterFLEX User's Guide provides detailed information on these configuration
options for the X11R5, X11/NeWS, and Loadable DDX Window System enviroments.
.sp 
If you are unsure about which of these options are appropriate, you
should probably use the default values at first.
.br
END_OF_FILE
"

#################################################################
# Do not perform overlay mode selection is a RasterFLEX-24
# is installed in the system.
#################################################################

ans=`ckyorn -d n -p "Would you like to select the configuration options? <n>"` || exit $?
if [ $ans = y -o $ans = yes ] 
then

   if [ -z "`prtconf | grep VITec,RasterFLEX-24`" ] 
   then
       FormatText "\
The RasterFLEX Overlay Mode refers to the manner in which the overlay bits
of the RasterFLEX accelerator are represented to the user.  Two different
choices are available: 4-bit Overlay Mode and 8-bit Overlay Mode.  Refer
to the RasterFLEX User's Guide for the capabilities and tradeoffs associated
with each mode.
.sp
The overlay capability is not available for the RasterFLEX-24 product.  In
this instance, select any value to continue.
.sp
Unless you are using an application which has specific overlay requirements,
you probably will want to use 4-bit overlay mode since it is significantly
more flexible.
.sp
.br
END_OF_FILE
"
        FourString="4-bit Overlay Mode"
        EightString="8-bit Overlay Mode"
        
        OverlayMode=`ckitem -n -p "Select the desired overlay mode:" "$FourString" "$EightString"` || exit $?
        echo $OverlayMode
        if [ "$OverlayMode" = "8-bit" -a "$WindowSystem" != "DDX" ]
        then
            ServerString="$ServerString -overlay8"
        fi
    fi

    FormatText "\
The default visual depth refers to the number of significant bits per
pixel associated
with the default visual.  The default visual is generally used by 
application programs which do not not explicitly request a visual of
a particular depth.  The RasterFLEX accelerator will support a default visual
depth of either 8 or 24 bits.  Refer to the RasterFLEX User's Guide
for more detailed information on visual selection.
.sp
.br
END_OF_FILE
"

    EightString="8-bit Default Visual Depth"
    TwentyFourString="24-bit Default Visual Depth"

    DepthSel=`ckitem -n -p "Select the desired default visual depth:" "$EightString" "$TwentyFourString"` || exit $?
    if [ "$DepthSel" = "8-bit" ]
    then
        if [ -n "$VITrxservDir" ]
        then
            ServerString="$ServerString -dd 8"
        else
            ServerString="$ServerString defdepth 8"
        fi
    else
        if [ -n "$VITrxservDir" ]
        then
            ServerString="$ServerString -dd 24"
        else
            ServerString="$ServerString defdepth 24"
        fi
    fi

    FormatText "\
The default visual class refers to the attributes of the colormap associated
with the default visual.  The default visual is generally used by 
application programs which do not not explicitly request a visual of
a particular class.  The RasterFLEX accelerator will support a wide 
variety of default visual classes depending upon the default depth.  
Refer to the RasterFLEX User's Guide
for more detailed information on visual selection.
.br
END_OF_FILE
"
    PseudoColorString="PseudoColor"
    StaticColorString="StaticColor"
    GrayScaleString="GrayScale"
    StaticGrayString="StaticGray"
    DirectColorString="DirectColor"
    TrueColorString="TrueColor"

    if [ "$DepthSel" = "8-bit" ]
    then

        ClassSel=`ckitem -n -p "Select the desired class:" $PseudoColorString $StaticColorString $GrayScaleString $StaticGrayString $DirectColorString $TrueColorString` || exit $? 

    else

        ClassSel=`ckitem -n -p "Select the desired class:" $DirectColorString $TrueColorString` || exit $? 

    fi

    case $WindowSystem in

    X11R5)
        ServerString="$ServerString -cc $ClassSel";;

    X11NEWS)
        case $ClassSel in
        "StaticGray")
            ServerString="$ServerString grayvis staticvis"
            ;;
        "GrayScale")
            ServerString="$ServerString grayvis"
            ;;
        "StaticColor" | "TrueColor")
            ServerString="$ServerString staticvis"
            ;;
        esac
	;;
    DDX)
        ServerString="$ServerString defclass $ClassSel"
        ;;
    esac
fi

#################################################################
# All finished.  Now prompt for a directory into which the
# shell file should be written. 
#################################################################
FormatText "\
Very well.  I have now completed generating the appropriate user
environment based upon the software installation locations and your
selections.  I am now prepared to write out the initialization
script required to prepare to use the RasterFLEX software.  I can
generate a C-shell and/or a Korn-shell script to do this.  Please
select the type of script to generate:
.br
END_OF_FILE
"

BothString="both Korn and C Shell initialization scripts"
CshString="csh C Shell initialization script named .cshrc.flex"
KshString="ksh  Korn Shell initialization script named .profile.flex"
ShellSel=`ckitem -n -p "Select the desired script type:" "$BothString" "$CshString" "$KshString"` || exit $? 
case $ShellSel in
both)
     MakeCsh="TRUE"
     MakeKsh="TRUE";;
csh)
     MakeCsh="TRUE"
     MakeKsh="";;
*)
     MakeCsh=""
     MakeKsh="TRUE";;
esac

#################################################################
# Prompt for the destination location
#################################################################
FormatText "\
You need to select the directory into which the .cshrc.flex file
(if you selected csh initialization) and/or .profile.flex (if you
selected ksh initialization) should be written.
.br
END_OF_FILE
"
while :
do
    DirPath=`ckpath -y -w -d "." -p "To which directory should I write the file(s) <.>"` || exit $?
    if [ ! -w "$DirPath" ]
    then
        EchoLn "You do not seem to have write permissions to this directory."
        continue
    fi
    if [ -n "$MakeCsh" -a -f $DirPath/.cshrc.flex ]
    then
        EchoLn "A file named .cshrc.flex already exists in this directory."
        ans=`ckyorn -d y -p "Should I replace it? <y>"` || exit $?
        if [ $ans = y -o $ans = yes ] 
        then
            rm $DirPath/.cshrc.flex
            if [ $? -ne 0 ]
            then
                EchoLn "I'm unable to remove the existing file."
                continue 
            fi
        else
            continue
        fi
    fi
    if [ -n "$MakeCsh" ]
    then
        touch $DirPath/.cshrc.flex 2> /dev/null
        if [ -f $DirPath/.cshrc.flex ]
        then
            rm $DirPath/.cshrc.flex
        else
            EchoLn "I do not appear to have permissions to write .cshrc.flex"
            continue
        fi
    fi
    if [ -n "$MakeKsh" -a -f $DirPath/.profile.flex ]
    then
        EchoLn "A file named .profile.flex already exists in this directory."
        ans=`ckyorn -d y -p "Should I replace it? <y>"` || exit $?
        if [ $ans = y -o $ans = yes ] 
        then
            rm $DirPath/.profile.flex
            if [ $? -ne 0 ]
            then
                EchoLn "I'm unable to remove the existing file."
                continue 
            fi
        else
            continue
        fi
    fi
    if [ -n "$MakeKsh" ]
    then
        touch $DirPath/.profile.flex 2> /dev/null
        if [ -f $DirPath/.profile.flex ]
        then
            rm $DirPath/.profile.flex
        else
            EchoLn "I do not appear to have permissions to write .profile.flex"
            continue
        fi
    fi
    break
done
    
FullPath=`cd $DirPath; pwd`

#################################################################
# Write the file
#################################################################
if [ -n "$MakeCsh" ]
then
    exec > $DirPath/.cshrc.flex
    echo "#!/bin/csh"
    echo "#"
    echo "# .cshrc.flex - Sample .cshrc entries for setting up the"
    echo "#               RasterFLEX user environment"
    echo "#"
    echo "# This file was generated automatically by the RasterFLEX"
    echo "# Software Configuration Utility Version $Version."
    echo "#"
    echo "# Add the following line to the end of the .cshrc file in"
    echo "# your home directory:"
    echo "#"
    echo "#   source $FullPath/.cshrc.flex"
    echo "#"
    echo "#"
    if [ -n "$OPENWINHOME" ]
    then
        echo "setenv OPENWINHOME $OPENWINHOME"
    fi
    echo "if ( \$?LD_LIBRARY_PATH ) then"
    echo "    setenv LD_LIBRARY_PATH $LibraryPath:\$LD_LIBRARY_PATH"
    echo "else"
    echo "    setenv LD_LIBRARY_PATH $LibraryPath"
    echo "endif"
    echo "if ( \$?MANPATH ) then"
    echo "    setenv MANPATH $ManPath:\$MANPATH"
    echo "else"
    echo "    setenv MANPATH /usr/man:$ManPath"
    echo "endif"
    echo "setenv PATH $ExecPath:\$PATH"
    echo "rehash"
    if [ -n "$VITrxservDir" -a -n "$VITrxfontDir" ]
    then
        echo "setenv PEX_FONTPATH $XFontsDir/PEX"
    fi
    if [ -n "$VITrxsuptDir" ]
    then
        echo "setenv XFILESEARCHPATH $VITrxsuptDir/lib/X11/app-defaults/%N"
    fi
    if [ -n "$VITrfddx" -a -n "$OverlayMode" -a "$OverlayMode" = "8-bit" ]
    then
        echo "setenv RFX_OVERLAY_MODE 8"
    fi
    echo "setenv SERVER \"$ServerString\""
    if [ -n "$OpenwinOptions" ]
    then
        echo "alias  openwin \"openwin $OpenwinOptions\""
    fi
    echo "alias  xinit \"xinit -- $ServerString\""
    exec > /dev/tty
fi
if [ -n "$MakeKsh" ]
then
    exec > $DirPath/.profile.flex
    echo "#"
    echo "# .profile.flex - Sample .profile entries for setting up the"
    echo "#                 RasterFLEX user environment"
    echo "#"
    echo "# This file was generated automatically by the RasterFLEX"
    echo "# Software Configuration Utility Version $Version."
    echo "#"
    echo "# Add the following lines to the end of the .profile file in"
    echo "# your home directory"
    echo "#"
    echo "#"
    if [ -n "$OPENWINHOME" ]
    then
        echo "OPENWINHOME=$OPENWINHOME; export OPENWINHOME"
    fi
    echo "if [ -n \"\$LD_LIBRARY_PATH\" ]"
    echo "then"
    echo "    LD_LIBRARY_PATH=$LibraryPath:\$LD_LIBRARY_PATH;"
    echo "else"
    echo "    LD_LIBRARY_PATH=$LibraryPath"
    echo "fi"
    echo "export LD_LIBRARY_PATH"
    echo "if [ -n \"\$MANPATH\" ]"
    echo "then"
    echo "    MANPATH=$ManPath:\$MANPATH"
    echo "else"
    echo "    MANPATH=/usr/man:$ManPath"
    echo "fi"
    echo "export MANPATH"
    echo "PATH=$ExecPath:\$PATH"
    echo "export PATH"
    if [ -n "$VITrxservDir" -a -n "$VITrxfontDir" ]
    then
        echo "PEX_FONTPATH=$XFontsDir/PEX"
        echo "export PEX_FONTPATH"
    fi
    if [ -n "$VITrxsuptDir" ]
    then
        echo "XFILESEARCHPATH=$VITrxsuptDir/lib/X11/app-defaults/%N"
        echo "export XFILESEARCHPATH"
    fi
    if [ -n "$VITrfddx" -a -n "$OverlayMode" -a "$OverlayMode" = "8-bit" ]
    then
        echo "RFX_OVERLAY_MODE=8"
        echo "export RFX_OVERLAY_MODE"
    fi
    echo "SERVER=\"$ServerString\""
    echo "export SERVER"
    if [ -n "$OpenwinOptions" ]
    then
        echo "openwin ()"
        echo "{"
        echo "openwin $OpenwinOptions"
        echo "}"
    fi
    echo "xinit ()"
    echo "{"
    echo "xinit -- $ServerString"
    echo "}"

    exec > /dev/tty
fi

#################################################################
# A final word from our sponsor.
#################################################################
if [ -n "$MakeCsh" ]
then
     FormatText "\
The file $DirPath/.cshrc.flex now contains the set of C shell environment
variable assignments and aliases required to use the RasterFLEX
software environment on your system.  To use this file, you should
probably append the following line to the end of the .cshrc in your 
home directory:
.sp
.ce 1
source $FullPath/.cshrc.flex
.fi
.sp
Once you have done this, log off the system and log back in.  You
should then be able to start the RasterFLEX window system environment
by typing \"xinit\" $OpenWinStr.
.br
END_OF_FILE
"
fi
if [ -n "$MakeKsh" ]
then
     FormatText "\
The file $DirPath/.profile.flex now contains the set of Korn shell environment
variable assignments and aliases required to use the RasterFLEX
software environment on your system.  To use this file, you should
probably append the file to the end of the .profile in your 
home directory:
.sp
.ce 1
cat $FullPath/.profile.flex >> \$HOME/.profile
.fi
.sp
Once you have done this, log off the system and log back in.  You
should then be able to start the RasterFLEX window system environment
by typing \"xinit\" $OpenWinStr.
.br
END_OF_FILE
"
fi
